const { default: isEmail } = require("validator/lib/isEmail");
const { genSaltSync, hashSync, compareSync } = require("bcrypt");
const Users = require("../Models/Users");
const { sign } = require("jsonwebtoken");

const createUser = async () => {
  const salt = genSaltSync(10);
  const password = hashSync(process.env.USER_PWD, salt);

  await Users.findOrCreate({
    where: { email: "admin@gmail.com" },
    defaults: {
      password,
    },
  });
};

const login = async (req, res) => {
  const { email, password } = req.body;
  if (!email) return res.status(400).json({ mssg: "Email field is required" });
  if (!isEmail(email)) return res.status(400).json({ mssg: "Invalid email" });
  if (!password)
    return res.status(400).json({ mssg: "Password field is required" });

  try {
    await createUser();

    const user = await Users.findOne({
      where: {
        email,
      },
    });
    if (!user) return res.status(400).json({ mssg: "Email doesn't exists" });

    if (!compareSync(password, user.dataValues.password))
      return res.status(400).json({ mssg: "Wrong password" });

    const token = sign({}, process.env.JWT_SECRET, { expiresIn: "30d" });

    return res.status(200).json({ token });
  } catch (e) {
    return res.status(400).json({ mssg: e.message });
  }
};

const resetPassword = async (req, res) => {
  const { newPassword } = req.body;
  if (!newPassword)
    return res.status(400).json({ mssg: "Address field is required" });

  try {
    const salt = genSaltSync(10);
    const password = hashSync(newPassword, salt);

    await Users.update(
      {
        password,
      },
      { where: {} }
    );

    return res.status(200).json({
      mssg: "Password changed",
    });
  } catch (e) {
    return res.status(400).json({ mssg: e.message });
  }
};

module.exports = {
  login,
  resetPassword,
};
