const Clients = require("../Models/Clients");

const getClients = async (req, res) => {
  try {
    const clients = await Clients.findAll({
      order: [["id", "DESC"]],
    });

    return res.status(200).json({ clients });
  } catch (e) {
    return res.status(400).json({ mssg: e.message });
  }
};

const addClient = async (req, res) => {
  const { name, phoneNumber, address } = req.body;
  if (!name) return res.status(400).json({ mssg: "Name field is required" });
  if (!phoneNumber)
    return res.status(400).json({ mssg: "Phone number field is required" });
  if (!address)
    return res.status(400).json({ mssg: "Address field is required" });

  try {
    const exists = await Clients.findOne({
      where: {
        name,
      },
    });
    if (exists)
      return res.status(400).json({
        mssg: "There are a client with this name",
      });

    const client = await Clients.create({
      name,
      phoneNumber,
      address,
    });

    return res.status(200).json({ client });
  } catch (e) {
    return res.status(400).json({ mssg: e.message });
  }
};

const editClient = async (req, res) => {
  const { name, phoneNumber, address, id } = req.body;
  if (!id) return res.status(400).json({ mssg: "Invalid ID" });
  if (!name) return res.status(400).json({ mssg: "Name field is required" });
  if (!phoneNumber)
    return res.status(400).json({ mssg: "Phone number field is required" });
  if (!address)
    return res.status(400).json({ mssg: "Address field is required" });

  try {
    const client = await Clients.findByPk(id);
    if (!client) return res.status(400).json({ mssg: "Invalid ID" });

    await Clients.update(
      {
        name,
        phoneNumber,
        address,
      },
      {
        where: {
          id,
        },
      }
    );

    return res.status(200).json({
      mssg: "Client details has been edited successfully",
    });
  } catch (e) {
    return res.status(400).json({ mssg: e.message });
  }
};

const deleteClients = async (req, res) => {
  const { id } = req.body;
  if (!id) return res.status(400).json({ mssg: "Invalid ID" });
  try {
    const client = await Clients.findByPk(id);
    if (!client) return res.status(400).json({ mssg: "Invalid ID" });

    await Clients.destroy({
      where: {
        id,
      },
    });

    return res.status(200).json({ mssg: "Client has been deleted" });
  } catch (e) {
    return res.status(400).json({ mssg: e.message });
  }
};

module.exports = {
  getClients,
  addClient,
  editClient,
  deleteClients,
};
