const Clients = require("../Models/Clients");
const Messages = require("../Models/Messages");

const getMessages = async (req, res) => {
  const { ClientId } = req.query;
  try {
    const messages = await Messages.findAll({
      include: [Clients],
      order: [["id", "DESC"]],
      where: {
        ClientId,
      },
    });

    return res.status(200).json({ messages });
  } catch (e) {
    return res.status(400).json({ mssg: e.message });
  }
};

const addMessage = async (req, res) => {
  const { message, ClientId } = req.body;
  if (!message)
    return res.status(400).json({ mssg: "Message field is required" });
  if (!ClientId)
    return res.status(400).json({ mssg: "Client id field is required" });

  try {
    const client = await Clients.findByPk(ClientId);
    if (!client) return res.status(400).json({ mssg: "Invalid client ID" });

    const createdMessage = await Messages.create({
      message,
      ClientId,
    });

    return res.status(200).json({ message: createdMessage });
  } catch (e) {
    return res.status(400).json({ mssg: e.message });
  }
};

const editMessage = async (req, res) => {
  const { message, id } = req.body;
  if (!id) return res.status(400).json({ mssg: "Invalid ID" });
  if (!message)
    return res.status(400).json({ mssg: "Message field is required" });

  try {
    const fetchedMessage = await Messages.findByPk(id);
    if (!fetchedMessage) return res.status(400).json({ mssg: "Invalid ID" });

    await Messages.update(
      {
        message,
      },
      {
        where: {
          id,
        },
      }
    );

    return res.status(200).json({
      mssg: "Message details has been edited successfully",
    });
  } catch (e) {
    return res.status(400).json({ mssg: e.message });
  }
};

const deleteMessages = async (req, res) => {
  const { id } = req.body;
  if (!id) return res.status(400).json({ mssg: "Invalid ID" });
  try {
    const message = await Messages.findByPk(id);
    if (!message) return res.status(400).json({ mssg: "Invalid ID" });

    await Messages.destroy({
      where: {
        id,
      },
    });

    return res.status(200).json({ mssg: "Message has been deleted" });
  } catch (e) {
    return res.status(400).json({ mssg: e.message });
  }
};

module.exports = {
  getMessages,
  addMessage,
  editMessage,
  deleteMessages,
};
