const Clients = require("../Models/Clients");
const Months = require("../Models/Months");
const Orders = require("../Models/Orders");
const SysManager = require("../Models/SysManager");

const monthsNames = [
  "Jan",
  "Feb",
  "Mar",
  "Apr",
  "May",
  "Jun",
  "Jul",
  "Aug",
  "Sep",
  "Oct",
  "Nov",
  "Dec",
];

const getHome = async (req, res) => {
  try {
    const clients = await Clients.findAll({
      order: [["id", "DESC"]],
    });
    const orders = await Orders.findAll({
      order: [["id", "DESC"]],
    });
    const sysManager = await SysManager.findByPk(1);
    const months = await Months.findAll();

    return res.status(200).json({
      profit: sysManager.dataValues.profit,
      capital: sysManager.dataValues.capital,
      clientsCount: clients.length,
      pendingOrdersCount: orders.filter(({ isCompleted }) => !isCompleted)
        .length,
      lastClients: clients.slice(0, 10),
      lastOrders: orders.slice(0, 10),
      months: months.map((month) => ({
        ...month.dataValues,
        month: monthsNames[month.dataValues.month],
        profit: month.profit * 1,
      })),
    });
  } catch (e) {
    return res.status(400).json({ mssg: e.message });
  }
};

module.exports = {
  getHome,
};
