const SysManager = require("../Models/SysManager");
const Transactions = require("../Models/Transactions");

const getTransactions = async (req, res) => {
  try {
    const transactions = await Transactions.findAll({
      order: [["id", "DESC"]],
    });
    const sysManager = await SysManager.findByPk(1);

    return res.status(200).json({
      transactions,
      capital: sysManager.dataValues.capital,
      profit: sysManager.dataValues.profit,
    });
  } catch (e) {
    return res.status(400).json({ mssg: e.message });
  }
};

const addTransaction = async (req, res) => {
  const { amount, isAdd, isCapital } = req.body;
  if (!amount)
    return res.status(400).json({ mssg: "Amount field is required" });

  try {
    const sysManager = await SysManager.findByPk(1);
    if (!isAdd)
      if (isCapital) {
        if (sysManager.dataValues.capital < amount)
          return res.status.json({
            mssg: "There is no enough money in capital",
          });
      } else {
        if (sysManager.dataValues.profit < amount)
          return res.status.json({
            mssg: "There is no enough money in profit",
          });
      }
    await SysManager.update(
      {
        capital: isCapital
          ? isAdd
            ? sysManager.dataValues.capital * 1 + amount * 1
            : sysManager.dataValues.capital * 1 - amount * 1
          : sysManager.dataValues.capital,
        profit: !isCapital
          ? isAdd
            ? sysManager.dataValues.profit * 1 + amount * 1
            : sysManager.dataValues.profit * 1 - amount * 1
          : sysManager.dataValues.profit,
      },
      {
        where: { id: 1 },
      }
    );

    const transaction = await Transactions.create({
      amount,
      isAdd,
      isCapital,
    });

    return res.status(200).json({ transaction });
  } catch (e) {
    return res.status(400).json({ mssg: e.message });
  }
};

const deleteTransactions = async (req, res) => {
  const { id } = req.body;
  if (!id) return res.status(400).json({ mssg: "Invalid ID" });
  try {
    const transactionToDelete = await Transactions.findByPk(id);
    if (!transactionToDelete)
      return res.status(400).json({ mssg: "Invalid ID" });

    let capital = 0;
    let profit = 0;

    const sysManager = await SysManager.findByPk(1);

    if (!transactionToDelete.dataValues.isCapital) {
      profit = transactionToDelete.dataValues.isAdd
        ? sysManager.dataValues.profit -
          transactionToDelete.dataValues.amount * 1
        : sysManager.dataValues.profit +
          transactionToDelete.dataValues.amount * 1;
    } else {
      capital = transactionToDelete.dataValues.isAdd
        ? sysManager.dataValues.capital -
          transactionToDelete.dataValues.amount * 1
        : sysManager.dataValues.capital +
          transactionToDelete.dataValues.amount * 1;
    }

    await SysManager.update(
      {
        capital: capital,
        profit: profit,
      },
      { where: { id: 1 } }
    );

    await Transactions.destroy({
      where: {
        id,
      },
    });

    return res.status(200).json({ mssg: "Transaction has been deleted" });
  } catch (e) {
    return res.status(400).json({ mssg: e.message });
  }
};

module.exports = {
  getTransactions,
  addTransaction,
  deleteTransactions,
};
