require("dotenv").config();
const express = require("express");
const clientsRouter = require("./Routes/Clients");
const ordersRouter = require("./Routes/Orders");
const deliveriesRouter = require("./Routes/Deliveries");
const messagesRouter = require("./Routes/Messages");
const transactionsRouter = require("./Routes/Transaction");
const app = express();
const cors = require("cors");
const sequelize = require("./db");
const authRouter = require("./Routes/Auth");
const { verify } = require("jsonwebtoken");
const SysManager = require("./Models/SysManager");
const sysManagerRouter = require("./Routes/SysManager");
const Orders = require("./Models/Orders");
const Months = require("./Models/Months");
const monthsRouter = require("./Routes/Months");

app.use(cors());
app.use(express.json());
app.use(async (req, res, next) => {
  try {
    await sequelize.sync({ alter: true });
    const [sysManager] = await SysManager.findOrCreate({
      where: { id: 1 },
    });
    const lastUpdatedMonth = new Date(
      sysManager.dataValues.updatedAt
    ).getMonth();
    const currentMonth = new Date().getMonth();
    if (lastUpdatedMonth != currentMonth) {
      const orders = await Orders.findAll({ where: { isCompleted: true } });
      await Months.create({
        month: currentMonth,
        profit: sysManager.dataValues.profit,
        orderCount: orders.length,
        capital: sysManager.dataValues.capital,
      });
      await Orders.destroy({ where: { isCompleted: true } });
      await SysManager.update(
        {
          profit: 0,
          capital:
            sysManager.dataValues.profit * 1 +
            sysManager.dataValues.capital * 1,
        },
        { where: { id: 1 } }
      );
    }
  } catch (e) {
    return res.status(400).json({ mssg: e.message });
  }
  next();
});

app.use(async (req, res, next) => {
  if (req.originalUrl === "/auth/login") return next();

  const authHeader = req.headers["authorization"];
  if (!authHeader)
    return res.status(401).json({ error: "Access denied, no token provided" });

  const token = authHeader.split(" ")[1];
  if (!token)
    return res.status(401).json({ error: "Access denied, no token provided" });

  try {
    verify(token, process.env.JWT_SECRET);

    next();
  } catch (err) {
    return res.status(403).json({ error: "Invalid or expired token" });
  }
});

app.use("/clients", clientsRouter);
app.use("/orders", ordersRouter);
app.use("/deliveries", deliveriesRouter);
app.use("/messages", messagesRouter);
app.use("/transactions", transactionsRouter);
app.use("/auth", authRouter);
app.use("/sys-manager", sysManagerRouter);
app.use("/months", monthsRouter);

app.listen(4000, () => console.log("On 4000"));
